#!/bin/sh
#
# author: Joerg Heinemann
# website: http://enterprise-log-management-appliance.org
# license: GPL v3
#
# /etc/cron.d/elma-config-backup.sh
#

RETVAL=0
#IFS="_"
OPTIONS=$@

SCRIPT_DESCRIPTION="openSUSE and ELMA config backup"
SCRIPT_AUTHOR="Joerg Heinemann"

# ######### Load ELMA configuration parameter, global functions and script header #########
#
source /etc/elma/elma.conf ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
source $ELMA_LIB_DIR/elma-global-functions.sh ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi

LATESTARCHIVEDATE=`date --date ${SYSCONFIG_ARCHIVE_PERIOD}' days ago' '+%Y-%m-%d'`

echo  --- `date +%T.%N | cut -c 1-12` - Creating openSUSE autoyast file ----------------------------------------
echo

if [ -f /root/autoinst.xml ]
then
	rm /root/autoinst.xml ; if [ $? -ne 0 ]; then exit; fi
fi

screen -D -m yast clone_system ; if [ $? -ne 0 ]; then exit; fi

if [ ! -d "$SYSCONFIG_BACKUP_DIR" ]
then
	mkdir "$SYSCONFIG_BACKUP_DIR"
fi
if [ -f /root/autoinst.xml ] && [ -d "$SYSCONFIG_BACKUP_DIR" ]
then
	mv /root/autoinst.xml "$SYSCONFIG_BACKUP_DIR"/opensuse-autoinst-$TODAY.xml ; if [ $? -ne 0 ]; then exit; fi
fi

echo  --- `date +%T.%N | cut -c 1-12` - Backup ELMA config files -----------------------------------------------
echo

if [ -f /etc/elma-config-$TODAY.tgz ]
then
	rm /etc/elma-config-$TODAY.tgz ; if [ $? -ne 0 ]; then exit; fi
fi

if [ -d /etc/apache2 ]
then
	BACKUPCONTENT="apache2 "
fi
if [ -d /etc/collectd ]
then
	BACKUPCONTENT=$BACKUPCONTENT"collectd "
fi
if [ -d /etc/crontab ]
then
	BACKUPCONTENT=$BACKUPCONTENT"crontab "
fi
if [ -d /etc/elasticsearch ]
then
	BACKUPCONTENT=$BACKUPCONTENT"elasticsearch "
fi
if [ -d /etc/elma ]
then
	BACKUPCONTENT=$BACKUPCONTENT"elma "
fi
if [ -d /etc/logrotate.d ]
then
	BACKUPCONTENT=$BACKUPCONTENT"logrotate.d "
fi
if [ -d /etc/nagios ]
then
	BACKUPCONTENT=$BACKUPCONTENT"nagios "
fi
if [ -d /etc/nagiosgraph ]
then
	BACKUPCONTENT=$BACKUPCONTENT"nagiosgraph "
fi
if [ -d /etc/named.d ]
then
	BACKUPCONTENT=$BACKUPCONTENT"named.d "
fi
if [ -d /etc/php5 ]
then
	BACKUPCONTENT=$BACKUPCONTENT"php5 "
fi
if [ -d /etc/rsyslog.d ]
then
	BACKUPCONTENT=$BACKUPCONTENT"rsyslog.d "
fi
if [ -d /etc/security ]
then
	BACKUPCONTENT=$BACKUPCONTENT"security "
fi
if [ -d /etc/snmp ]
then
	BACKUPCONTENT=$BACKUPCONTENT"snmp "
fi
if [ -d /etc/sysconfig ]
then
	BACKUPCONTENT=$BACKUPCONTENT"sysconfig "
fi
if [ -d /etc/systemd ]
then
	BACKUPCONTENT=$BACKUPCONTENT"systemd "
fi
if [ -d /etc/zypp ]
then
	BACKUPCONTENT=$BACKUPCONTENT"zypp "
fi

if [ -f /etc/init.d/boot.local ]
then
	BACKUPCONTENT=$BACKUPCONTENT"init.d/boot.local "
fi
if [ -f /etc/HOSTNAME ]
then
	BACKUPCONTENT=$BACKUPCONTENT"HOSTNAME "
fi
if [ -f /etc/hosts ]
then
	BACKUPCONTENT=$BACKUPCONTENT"hosts "
fi
if [ -f /etc/named.conf ]
then
	BACKUPCONTENT=$BACKUPCONTENT"named.conf "
fi
if [ -f /etc/ntp.conf ]
then
	BACKUPCONTENT=$BACKUPCONTENT"ntp.conf "
fi
if [ -f /etc/permissions.local ]
then
	BACKUPCONTENT=$BACKUPCONTENT"permissions.local "
fi
if [ -f /etc/resolv.conf ]
then
	BACKUPCONTENT=$BACKUPCONTENT"resolv.conf "
fi
if [ -f /etc/rsyslog.conf ]
then
	BACKUPCONTENT=$BACKUPCONTENT"rsyslog.conf "
fi
if [ -f /etc/sudoers ]
then
	BACKUPCONTENT=$BACKUPCONTENT"sudoers "
fi
if [ -f /etc/os-release ]
then
	BACKUPCONTENT=$BACKUPCONTENT"os-release "
fi
if [ -f /etc/products.d/openSUSE.prod ]
then
	BACKUPCONTENT=$BACKUPCONTENT"products.d/openSUSE.prod "
fi
if [ -f /etc/ImagePackages ]
then
	BACKUPCONTENT=$BACKUPCONTENT"ImagePackages "
fi
if [ -f /etc/ImageVersion ]
then
	BACKUPCONTENT=$BACKUPCONTENT"ImageVersion "
fi
if [ -f /etc/SUSE-brand ]
then
	BACKUPCONTENT=$BACKUPCONTENT"SUSE-brand "
fi
if [ -f /etc/SuSE-release ]
then
	BACKUPCONTENT=$BACKUPCONTENT"SuSE-release"
fi

cd /etc ; tar -cvzf elma-config-$TODAY.tgz $BACKUPCONTENT

# Removed from backup
#
# /etc/logstash
#

if [ -f /etc/elma-config-$TODAY.tgz ] && [ -d "$SYSCONFIG_BACKUP_DIR" ]
then
	mv /etc/elma-config-$TODAY.tgz "$SYSCONFIG_BACKUP_DIR" ; if [ $? -ne 0 ]; then exit; fi
fi

echo

#echo  ===========================================================================================
#echo
#echo  "Last log archive:		$LATESTARCHIVEDATE"
#echo  "Days in log archive:		$ES_ARCHIVE_PERIOD"
#echo  "Actual number of indexes:	"`curl $ES_AUTH -s $ES_URL/_status?pretty=true |grep index |grep -v { |sort |uniq |awk -F\" '{print $4}' |wc -l`
#echo
echo  ===========================================================================================
echo