#!/bin/sh
#
# author: Joerg Heinemann
# website: http://enterprise-log-management-appliance.org
# license: GPL v3
#
# /usr/share/elma/bin/elma-reconfigure.sh
#

RETVAL=0
LOGGING=0
#IFS="_"
OPTIONS=$@

SCRIPT_DESCRIPTION="ELMA - System setup, diagnostics and updates"
SCRIPT_AUTHOR="Joerg Heinemann"

# ######### Load ELMA configuration parameter, global functions and script header #########
#
source /etc/elma/elma.conf ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
source $ELMA_LIB_DIR/elma-global-functions.sh ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi

# ######### Checking command line options #########
#
if [ -z "$*" ]; then
	script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
	script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
	reconfigure_elma_services ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
fi

while test -n "$1"; do
	case "$1" in
	''|"")
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_elma_services ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--all)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_elma_services ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--apache)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_apache_service ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--collectd)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_collectd_service ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--diag)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		system_diagnostics ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--dns)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_dns_service ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--elasticsearch)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_elasticsearch_service ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--firewall)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_susefirewall_service ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--firstboot)
		if [ $LOGGING -eq 0 ]; then
#			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
#			LOGGING=1
		fi
		reconfigure_firstboot ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--ftp)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_ftp_service ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--install)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		install_opensuse_packages ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		reconfigure_elma_services ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--kibana)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_kibana3 ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--logstash)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_logstash_service ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--nagios)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_nagios_core_service ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--network)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_network_service ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--ntp)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_ntp_service ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--patch)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		patch_opensuse_packages ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		reconfigure_elma_services ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--patch-config)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		check_config_file_diffs ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		reconfigure_elma_services ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--postfix)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_postfix_service ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--proxy)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_proxy_configuration ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--reboot)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		system_reboot ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--repositories)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_update_repositories "status"; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--reset)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		config_reset ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--rsyslog)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_rsyslog_service ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--snmp)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_snmpd_service ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--snmptrap)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_snmptrapd_service ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--update)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		update_opensuse_packages ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		reconfigure_elma_services ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--webyast)
		if [ $LOGGING -eq 0 ]; then
			script_logging ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			script_header $OPTIONS ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
			LOGGING=1
		fi
		reconfigure_webyast_service ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		shift
		;;
	--internet)
		check_internet_access "status" ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		exit
		;;
	--config-status)
		check_config_file_diffs "status" ; if [ $? -ne 0 ]; then error_exit "$LINENO"; fi
		exit
		;;
	*)
		echo
		echo "$(basename $0): invalid option -- '$1'" >&2
		echo "$(basename $0): Usage: $(basename $0) <options>" >&2
		echo
		echo "Options:"
		echo
		echo "--help                    Display this help message and exit"
		echo
		echo "--all                     Reconfigure all below services"
		echo "--apache                  Reconfigure Apache2 web service"
		echo "--collectd                Reconfigure collectd service"
		echo "--config-status           Check ELMA config file differences"
		echo "--diag                    System diagnostics - File system checks and cleanup"
		echo "--dns                     Reconfigure DNS service"
		echo "--elasticsearch           Reconfigure elasticsearch service"
		echo "--firewall                Reconfigure services to be configured during first boot"
		echo "--firstboot               Reconfigure SuSEfirewall service"
		echo "--ftp                     Reconfigure FTP service"
		echo "--install                 Install required system packages"
		echo "--internet                Check internet access"
		echo "--kibana                  Reconfigure Kibana3 service"
		echo "--logstash                Reconfigure logstash service"
		echo "--nagios                  Reconfigure Nagios service"
		echo "--network                 Reconfigure Network service"
		echo "--ntp                     Reconfigure NTP service"
		echo "--patch                   Apply needed patches"
		echo "--patch-config            Patch ELMA config file"
		echo "--postfix                 Reconfigure postfix service"
		echo "--proxy                   Reconfigure proxy configuration"
		echo "--reboot                  System reboot"
		echo "--repositories            Reconfigure system distribution repositories"
		echo "--reset                   Reset ELMA configuration parameter to factory defaults"
		echo "--rsyslog                 Reconfigure rsyslog service"
		echo "--snmp                    Reconfigure snmpd service"
		echo "--snmptrap                Reconfigure snmptrapd service"
		echo "--update                  Update system packages to newest available versions"
		echo "--webyast                 Reconfigure webyast service"
		echo
		exit 1
		;;
	esac
done

# ######### Final checks of install process #########
#
if [ $RETVAL -eq 0 ]
then
	echo "==========================================================================================="
	echo "PASS: Successful"
	echo "==========================================================================================="
	echo
	check_disk_usage
	check_packages_status
	check_config_file_patches
	update_recommendations
	reboot_recommendations
	echo
else
	echo "ABORT - Please check above error messages and installation log file!"
	echo
	exit 1
fi

# ######### Time to close output and error named pipes #########
#
sleep 1